==> 1.0.43+1.tar.gz: lib/components/UikScrollProducts.dart <==
// dog_card.dart

import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikScrollProductsProps.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

class UikScrollProducts extends UikWidget {
  WidgetType _widgetType;
  UikScrollProductsProps _UikScrollProductsProps;
  UikScrollProducts(this._widgetType, this._UikScrollProductsProps)
      : super(_widgetType, _UikScrollProductsProps);

  @override
  _UikScrollProductsState createState() =>
      _UikScrollProductsState(_UikScrollProductsProps);
}

class MyCustomScrollBehavior extends MaterialScrollBehavior {
  // Override behavior methods and getters like dragDevices
  @override
  Set<PointerDeviceKind> get dragDevices => {
        PointerDeviceKind.touch,
        PointerDeviceKind.mouse,
        // etc.
      };
}

class _UikScrollProductsState extends State<UikScrollProducts> {
  UikScrollProductsProps _UikScrollProductsProps;
  _UikScrollProductsState(this._UikScrollProductsProps);
  final ScrollController controller = ScrollController();

  @override
  Widget build(BuildContext context) {
    return _UikScrollProductsProps.pl.length != null
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              //..................................In the Spotlight....................................//
              Container(
                margin: EdgeInsets.only(
                  bottom: _UikScrollProductsProps.topHeadingMargin,
                  top: _UikScrollProductsProps.topHeadingMargin,
                  left: _UikScrollProductsProps.leftHeadingMargin,
                  right: _UikScrollProductsProps.rightHeadingMargin,
                ),
                width: _UikScrollProductsProps.headingWidth,
                height: _UikScrollProductsProps.headingHeight,
                child: (_UikScrollProductsProps.heading != null)
                    ? _UikScrollProductsProps.heading!
                    : const Text(""),
              ),

              //......................................Products........................................//
              Container(
                height: _UikScrollProductsProps.height,
                width: _UikScrollProductsProps.width,
                margin: EdgeInsets.only(
                  top: _UikScrollProductsProps.topMargin,
                  bottom: _UikScrollProductsProps.bottomMargin,
                  right: _UikScrollProductsProps.rightMargin,
                  left: _UikScrollProductsProps.leftMargin,
                ),
                // margin: EdgeInsets.only(left: 17),
                child: ScrollConfiguration(
                  behavior: MyCustomScrollBehavior(),
                  child: ListView(
                    // ignore: sort_child_properties_last
                    children: [
                      for (int i = 0;
                          i < _UikScrollProductsProps.pl.length;
                          i++) ...[
                        _UikScrollProductsProps.pl[i],
                        SizedBox(
                          width: _UikScrollProductsProps.gapBetweenItems,
                        ),
                      ],
                    ],
                    scrollDirection: _UikScrollProductsProps.scrollAxis,
                    // controller: controller,
                  ),
                ),
              ),
            ],
          )
        : const Text("");
  }
}

==> 1.0.75+1.tar.gz: lib/components/UikScrollProducts.dart <==
// dog_card.dart

import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikScrollProductsProps.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

class UikScrollProducts extends UikWidget {
  WidgetType _widgetType;
  UikScrollProductsProps _UikScrollProductsProps;
  UikScrollProducts(this._widgetType, this._UikScrollProductsProps)
      : super(_widgetType, _UikScrollProductsProps);

  @override
  _UikScrollProductsState createState() =>
      _UikScrollProductsState(_UikScrollProductsProps);
}

class MyCustomScrollBehavior extends MaterialScrollBehavior {
  // Override behavior methods and getters like dragDevices
  @override
  Set<PointerDeviceKind> get dragDevices => {
        PointerDeviceKind.touch,
        PointerDeviceKind.mouse,
        // etc.
      };
}

class _UikScrollProductsState extends State<UikScrollProducts> {
  UikScrollProductsProps _UikScrollProductsProps;
  _UikScrollProductsState(this._UikScrollProductsProps);
  final ScrollController controller = ScrollController();

  @override
  Widget build(BuildContext context) {
    return _UikScrollProductsProps.items.length != null
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              //..................................In the Spotlight....................................//
              Container(
                margin: EdgeInsets.only(
                  bottom: _UikScrollProductsProps.topHeadingMargin,
                  top: _UikScrollProductsProps.topHeadingMargin,
                  left: _UikScrollProductsProps.leftHeadingMargin,
                  right: _UikScrollProductsProps.rightHeadingMargin,
                ),
                width: _UikScrollProductsProps.headingWidth,
                height: _UikScrollProductsProps.headingHeight,
                child: (_UikScrollProductsProps.heading != null)
                    ? _UikScrollProductsProps.heading!
                    : const Text(""),
              ),

              //......................................Products........................................//
              Container(
                height: _UikScrollProductsProps.height,
                width: _UikScrollProductsProps.width,
                margin: EdgeInsets.only(
                  top: _UikScrollProductsProps.topMargin,
                  bottom: _UikScrollProductsProps.bottomMargin,
                  right: _UikScrollProductsProps.rightMargin,
                  left: _UikScrollProductsProps.leftMargin,
                ),
                // margin: EdgeInsets.only(left: 17),
                child: ScrollConfiguration(
                  behavior: MyCustomScrollBehavior(),
                  child: ListView(
                    // ignore: sort_child_properties_last
                    children: [
                      for (int i = 0;
                          i < _UikScrollProductsProps.items.length;
                          i++) ...[
                        _UikScrollProductsProps.items[i],
                        SizedBox(
                          width: _UikScrollProductsProps.gapBetweenItems,
                        ),
                      ],
                    ],
                    scrollDirection: _UikScrollProductsProps.scrollAxis,
                    // controller: controller,
                  ),
                ),
              ),
            ],
          )
        : const Text("");
  }
}
